(function() {
  var FieldParser, SwiftParser, block1Parser, block2Parser, finParser, fs, main, mtParser;

  fs = require('fs');

  finParser = require("./finParser.js");

  mtParser = require("./mtParser.js");

  block1Parser = require('./block1Parser');

  block2Parser = require('./block2Parser');

  FieldParser = require('./FieldRegexpFactory').FieldParser;

  SwiftParser = class SwiftParser {
    constructor(fieldPatterns1) {
      this.fieldPatterns = fieldPatterns1;
      if (typeof fieldPatterns === "undefined" || fieldPatterns === null) {
        this.fieldPatterns = JSON.parse(fs.readFileSync(__dirname + '/metadata/patterns.json'));
      }
      this.fieldParser = new FieldParser(this.fieldPatterns);
    }

    process(swiftMessage) {
      var ast, field, fieldCode, i, len, parsedField, ref, ref1;
      ast = finParser.parse(swiftMessage);
      ast.block1 = block1Parser.parse(ast.block1.content[0]);
      ast.block2 = block2Parser.parse(ast.block2.content[0]);
      ast.block4.fields = mtParser.parse(ast.block4.content[0]);
      ref = ast.block4.fields;
      for (i = 0, len = ref.length; i < len; i++) {
        field = ref[i];
        fieldCode = field.type + ((ref1 = field.option) != null ? ref1 : "");
        parsedField = this.fieldParser.parse(fieldCode, field.fieldValue);
        field.ast = parsedField;
      }
      return ast;
    }

    async parse(swiftMessage) {
      var ast, e;
      try {
        ast = (await this.process(swiftMessage));
        return ast;
      } catch (error) {
        e = error;
        return e;
      }
    }

  };

  module.exports.SwiftParser = SwiftParser;

  main = function() {
    var filename;
    if (process.argv.length !== 3) {
      console.log("Usage: node swiftParser <swift file>");
      return;
    }
    filename = process.argv[2];
    return fs.readFile(filename, "ASCII", function(err, content) {
      var parser;
      if ((err != null)) {
        throw err;
      }
      parser = new SwiftParser();
      return parser.parse(content, function(err, ast) {
        if ((err != null)) {
          throw err;
        }
        return console.log(JSON.stringify(ast, null, 2));
      });
    });
  };

  if (require.main === module) {
    main();
  }

}).call(this);

//# sourceMappingURL=swiftParser.js.map
